#!/bin/sh -e

# vars to get configure to locate bluez
export THIRDPARTY_BASE_DIR="`pwd`/../../.."

CONFFLAGS=""

case "$1" in
s3c24xx)
	PLATFORM="s3c24xx"
	CROSS_BUILD="i686-linux"
	CROSS_TARGET="arm-linux"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920"
	;;
s3c64xx)
	PLATFORM="s3c64xx"
	CROSS_BUILD="i686-pc-linux-gnu"
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm1176jzf-s"
	;;
x86)
	PLATFORM="x86"
	CROSS_CPU="i686"
	CROSS_OPT="-m32"
	;;
qemu-arm)
	PLATFORM="qemu-arm"
	CROSS_BUILD="i686-pc-linux-gnu"
	#CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	# using temp CodeSourcery toolchain from R1 SiRF BSP drop
	CROSS_TARGET="arm-none-linux-gnueabi"
	CROSS_OPT="-O2"
	CROSS_CPU="arm920t"
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	exit 1
	;;
esac

PROGNAME="opkg"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}"
INSDIR="${PWD}/ins-${PLATFORM}"

if [ $PLATFORM != "x86" ] 
then
	export BUILD_CC="gcc"
	export CC="${CROSS_TARGET}-gcc"
	export CXX="${CROSS_TARGET}-g++"
	export F77="${CROSS_TARGET}-g77"
	export AS="${CROSS_TARGET}-as"
	export LD="${CROSS_TARGET}-ld"
	export AR="${CROSS_TARGET}-ar"
	export NM="${CROSS_TARGET}-nm"
	export RANLIB="${CROSS_TARGET}-ranlib"
	export STRIP="${CROSS_TARGET}-strip"
	export ac_cv_func_malloc_0_nonnull="yes"
fi
export CFLAGS="${CROSS_OPT} -mcpu=${CROSS_CPU} -ffunction-sections -fdata-sections "
export CXXFLAGS="${CFLAGS}"
export LDFLAGS="-Wl,--gc-sections"

mkdir -p "${OBJDIR}"
cd "${OBJDIR}"

ZLIB_CFLAGS="-I${THIRDPARTY_BASE_DIR}/zlib/dist/1.2.3/Include"
ZLIB_LIBS="-L${THIRDPARTY_BASE_DIR}/zlib/dist/1.2.3/Linux/lib-${PLATFORM}"

export CFLAGS="${CFLAGS} ${ZLIB_CFLAGS}"
export LDFLAGS="${LDFLAGS} ${ZLIB_LIBS}"

echo "**** Configuring ${PROGNAME} for ${PLATFORM}..."
"${SRCDIR}/configure"		\
  --build="${CROSS_BUILD}"	\
  --host="${CROSS_TARGET}"	\
  --target="${CROSS_TARGET}"	\
  --disable-curl		\
  --disable-gpg			\
  --prefix=""			\
  --program-prefix=""		\
  ${CONFFLAGS}

echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"

# EOF
